@@ -1,4 +1,4 @@
-extractAIC.logregr.madlib <- function(fit, scale=0, k=2, ...)
+extractAIC.glm.madlib <- extractAIC.logregr.madlib <- function(fit, scale=0, k=2, ...)
 {
     edf <- length(fit$coef)
     c(edf, -2 * fit$log_likelihood + k * edf)
@@ -6,7 +6,7 @@ extractAIC.logregr.madlib <- function(fit, scale=0, k=2, ...)
 
 ## ----------------------------------------------------------------------
 
-logLik.logregr.madlib <- function(object, ...)
+logLik.glm.madlib <- logLik.logregr.madlib <- function(object, ...)
 {
     ll <- object$log_likelihood
     attr(ll, "df") <- length(object$coef)
@@ -16,16 +16,16 @@ logLik.logregr.madlib <- function(object, ...)
 
 ## ----------------------------------------------------------------------
 
-extractAIC.logregr.madlib.grps <- function(fit, scale=0, k=2, ...)
+extractAIC.glm.madlib.grps <- extractAIC.logregr.madlib.grps <- function(fit, scale=0, k=2, ...)
     lapply(fit, extractAIC, scale=scale, k=k, ...)
 
 ## ----------------------------------------------------------------------
 
-logLik.logregr.madlib.grps <- function(object, ...)
+logLik.glm.madlib.grps <- logLik.logregr.madlib.grps <- function(object, ...)
     lapply(object, logLik, ...)
 
 ## ----------------------------------------------------------------------
 
-AIC.logregr.madlib.grps <- function(object, ..., k=2)
+AIC.glm.madlib.grps <- AIC.logregr.madlib.grps <- function(object, ..., k=2)
     sapply(object, AIC, k=k, ...)
 
